@@ -1,13 +1,48 @@
+(function () {
+  var hooks = {
+    request: [],
+    response: []
+  }
+
+  window.restfx = {
+    _hooks: hooks,
+    on: function (hookName, handler) {
+      if (!hooks.hasOwnProperty(hookName)) {
+        console.error('Invalid hookName "%s", expected %s', hookName, Object.keys(hooks).join('/'))
+        return
+      }
+      hooks[hookName].push(handler)
+    }
+  }
+})()
+
+
 function loadPage() {
   // 请求数据
   var loading = $('#loading')
   loading.show()
-  $.post(urlRoot + '/' + apiPrefix, function (data, status, xhr) {
-    if (xhr.status !== 200) {
-      list.innerHTML = xhr.responseText
-      return
+  xhr('post', urlRoot + '/' + apiPrefix, {
+    callback: function (response) {
+      var data = response.data
+      if (response.status !== 200) {
+        loading.hide()
+
+        var content = ''
+        if (response.status) {
+          content = response.headers['content-type'].indexOf('text/html') === -1 ?
+            el('pre', null, data) : el('p', null, data)
+        }
+
+        list.append(el('div', {
+          'class': 'load-error'
+        }, [
+          el('h3', null, response.status ? response.statusText : 'No responding'),
+          content
+        ])).show()
+        return
+      }
+      render(list, typeof data === 'string' ? JSON.parse(data) : data)
     }
-    render(list, typeof data === 'string' ? JSON.parse(data) : data)
   })
 
   var app = $('#app')
