@@ -1,15 +1,14 @@
 import os
 from typing import List, Optional
 
-from .interfaces import ISessionProvider, IDbSessionProvider
+from .interfaces import IDbSessionProvider, ISessionProvider
 from .session import HttpSession
-from ..util import b64
 
 
 class MemorySessionProvider(ISessionProvider):
-    def __init__(self, expired: int, *args, **kwargs):
+    def __init__(self, expired: int = None):
         self.sessions = {}
-        super().__init__(expired, *args, **kwargs)
+        super().__init__(expired)
 
     def remove(self, session_id: str):
         if self.exists(session_id):
@@ -37,12 +36,12 @@ class MemorySessionProvider(ISessionProvider):
 
 
 class FileSessionProvider(ISessionProvider):
-    def __init__(self, expired: int, sessions_root: str, *args, **kwargs):
+    def __init__(self, sessions_root: str, expired: int = None):
         self.sessions_root = os.path.abspath(os.path.join(sessions_root, 'restfx_sessions'))
         if not os.path.exists(self.sessions_root):
             os.makedirs(self.sessions_root)
             # print('mkdir:' + self.sessions_root)
-        super().__init__(expired, *args, **kwargs)
+        super().__init__(expired)
 
     def _get_session_path(self, session_id: str) -> str:
         # session_id 中可能存在 / 符号
@@ -118,16 +117,16 @@ class FileSessionProvider(ISessionProvider):
 
 
 class MySQLSessionProvider(IDbSessionProvider):
-    def __init__(self, pool_options: dict, table_name="restfx_sessions", expired=20, *args, **kwargs):
+    def __init__(self, pool_options: dict, table_name="restfx_sessions", expired: int = None):
         self.table_name = table_name
 
-        super().__init__(pool_options, expired, *args, **kwargs)
+        super().__init__(pool_options, expired)
 
     def execute(self, sql: str, *args):
         import pymysql
         conn = self.connect()
 
-        # print('[MySQLSessionProvider] %s (%s)' % (sql, ','.join([str(i) for i in args])))
+        # print('[MySQLSessionProvider] ' + (sql % args))
 
         cursor = None
         try:
@@ -160,11 +159,11 @@ class MySQLSessionProvider(IDbSessionProvider):
 
     def create_table(self):
         self.execute("""CREATE TABLE `{table_name}` (
-        id VARCHAR(256) PRIMARY KEY NOT NULL,
-        creation_time LONG NOT NULL,
-        last_access_time LONG NOT NULL,
-        store TEXT,
-        INDEX last_access(last_access_time(8) ASC)
+        `id` VARCHAR(256) PRIMARY KEY NOT NULL,
+        `creation_time` BIGINT NOT NULL,
+        `last_access_time` BIGINT NOT NULL,
+        `store` BLOB,
+        INDEX `last_access`(`last_access_time`(8) ASC)
         ) ENGINE=InnoDB DEFAULT CHARSET=utf8""".format(table_name=self.table_name))
 
     def get_expired_session(self, time_before: float) -> List[str]:
@@ -181,21 +180,24 @@ class MySQLSessionProvider(IDbSessionProvider):
             session_id)
         if rows == 0:
             return None
-        item = data[0]
-        item['store'] = b64.dec_bytes(item['store'])
-        return self.parse(item)
+        return self.parse(data[0])
 
     def upsert(self, session_id: str, creation_time: float, last_access_time: float, store: bytes):
-        data = b64.enc_str(store)
+        # 检查存储数据长度，如果大于 65535 则抛出异常
+        store_len = len(store)
+        max_value = 65535
+        if store_len > max_value:
+            raise RuntimeError('Entity is too large (%s) for session storage, the max value is %s.' % (
+                store_len, max_value))
 
         self.execute("""INSERT INTO `{table_name}` VALUES(%s, %s, %s, %s) ON DUPLICATE KEY UPDATE
         last_access_time=%s, store=%s""".format(table_name=self.table_name),
                      session_id,
                      int(creation_time),
                      int(last_access_time),
-                     data,
+                     store,
                      int(last_access_time),
-                     data)
+                     store)
 
     def exists(self, session_id: str) -> bool:
         rows, _ = self.execute("""SELECT 1 FROM `{table_name}` WHERE `id`=%s limit 1""".format(
@@ -207,3 +209,4 @@ class MySQLSessionProvider(IDbSessionProvider):
 
     def dispose(self):
         self.execute('TRUNCATE TABLE `{table_name}`'.format(table_name=self.table_name))
+        super().dispose()
